@@ -19,9 +19,9 @@ use uucore::error::FromIo;
 use uucore::error::{UError, UResult, USimpleError};
 use uucore::fsext::{read_fs_list, MountInfo};
 use uucore::parse_size::ParseSizeError;
-use uucore::{format_usage, show};
+use uucore::{format_usage, help_about, help_section, help_usage, show};
 
-use clap::{crate_version, Arg, ArgMatches, Command, ValueSource};
+use clap::{crate_version, parser::ValueSource, Arg, ArgAction, ArgMatches, Command};
 
 use std::error::Error;
 use std::ffi::OsString;
@@ -33,16 +33,9 @@ use crate::columns::{Column, ColumnError};
 use crate::filesystem::Filesystem;
 use crate::table::Table;
 
-static ABOUT: &str = "Show information about the file system on which each FILE resides,\n\
-                      or all file systems by default.";
-const USAGE: &str = "{} [OPTION]... [FILE]...";
-const LONG_HELP: &str = "Display values are in units of the first available SIZE from --block-size,
-and the DF_BLOCK_SIZE, BLOCK_SIZE and BLOCKSIZE environment variables.
-Otherwise, units default to 1024 bytes (or 512 if POSIXLY_CORRECT is set).
-
-SIZE is an integer and optional unit (example: 10M is 10*1024*1024).
-Units are K, M, G, T, P, E, Z, Y (powers of 1024) or KB, MB,... (powers
-of 1000).";
+const ABOUT: &str = help_about!("df.md");
+const USAGE: &str = help_usage!("df.md");
+const AFTER_HELP: &str = help_section!("after help", "df.md");
 
 static OPT_HELP: &str = "help";
 static OPT_ALL: &str = "all";
@@ -105,11 +98,11 @@ impl Default for Options {
         Self {
             show_local_fs: Default::default(),
             show_all_fs: Default::default(),
-            block_size: Default::default(),
-            human_readable: Default::default(),
-            header_mode: Default::default(),
-            include: Default::default(),
-            exclude: Default::default(),
+            block_size: BlockSize::default(),
+            human_readable: Option::default(),
+            header_mode: HeaderMode::default(),
+            include: Option::default(),
+            exclude: Option::default(),
             sync: Default::default(),
             show_total: Default::default(),
             columns: vec![
@@ -146,10 +139,10 @@ impl fmt::Display for OptionsError {
             }
             // TODO This needs to vary based on whether `--block-size`
             // or `-B` were provided.
-            Self::InvalidBlockSize(s) => write!(f, "invalid --block-size argument {}", s),
+            Self::InvalidBlockSize(s) => write!(f, "invalid --block-size argument {s}"),
             // TODO This needs to vary based on whether `--block-size`
             // or `-B` were provided.
-            Self::InvalidSuffix(s) => write!(f, "invalid suffix in --block-size argument {}", s),
+            Self::InvalidSuffix(s) => write!(f, "invalid suffix in --block-size argument {s}"),
             Self::ColumnError(ColumnError::MultipleColumns(s)) => write!(
                 f,
                 "option --output: field {} used more than once",
@@ -187,9 +180,9 @@ impl Options {
         }
 
         Ok(Self {
-            show_local_fs: matches.contains_id(OPT_LOCAL),
-            show_all_fs: matches.contains_id(OPT_ALL),
-            sync: matches.contains_id(OPT_SYNC),
+            show_local_fs: matches.get_flag(OPT_LOCAL),
+            show_all_fs: matches.get_flag(OPT_ALL),
+            sync: matches.get_flag(OPT_SYNC),
             block_size: read_block_size(matches).map_err(|e| match e {
                 ParseSizeError::InvalidSuffix(s) => OptionsError::InvalidSuffix(s),
                 ParseSizeError::SizeTooBig(_) => OptionsError::BlockSizeTooLarge(
@@ -201,13 +194,13 @@ impl Options {
                 ParseSizeError::ParseFailure(s) => OptionsError::InvalidBlockSize(s),
             })?,
             header_mode: {
-                if matches.contains_id(OPT_HUMAN_READABLE_BINARY)
-                    || matches.contains_id(OPT_HUMAN_READABLE_DECIMAL)
+                if matches.get_flag(OPT_HUMAN_READABLE_BINARY)
+                    || matches.get_flag(OPT_HUMAN_READABLE_DECIMAL)
                 {
                     HeaderMode::HumanReadable
-                } else if matches.contains_id(OPT_PORTABILITY) {
+                } else if matches.get_flag(OPT_PORTABILITY) {
                     HeaderMode::PosixPortability
-                // contains_id() doesn't work here, it always returns true because OPT_OUTPUT has
+                // get_flag() doesn't work here, it always returns true because OPT_OUTPUT has
                 // default values and hence is always present
                 } else if matches.value_source(OPT_OUTPUT) == Some(ValueSource::CommandLine) {
                     HeaderMode::Output
@@ -216,9 +209,9 @@ impl Options {
                 }
             },
             human_readable: {
-                if matches.contains_id(OPT_HUMAN_READABLE_BINARY) {
+                if matches.get_flag(OPT_HUMAN_READABLE_BINARY) {
                     Some(HumanReadable::Binary)
-                } else if matches.contains_id(OPT_HUMAN_READABLE_DECIMAL) {
+                } else if matches.get_flag(OPT_HUMAN_READABLE_DECIMAL) {
                     Some(HumanReadable::Decimal)
                 } else {
                     None
@@ -226,7 +219,7 @@ impl Options {
             },
             include,
             exclude,
-            show_total: matches.contains_id(OPT_TOTAL),
+            show_total: matches.get_flag(OPT_TOTAL),
             columns: Column::from_matches(matches).map_err(OptionsError::ColumnError)?,
         })
     }
@@ -240,7 +233,7 @@ impl Options {
             }
         }
 
-        (!intersected_types.is_empty()).then(|| intersected_types)
+        (!intersected_types.is_empty()).then_some(intersected_types)
     }
 }
 
@@ -443,7 +436,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
 
     #[cfg(windows)]
     {
-        if matches.contains_id(OPT_INODES) {
+        if matches.get_flag(OPT_INODES) {
             println!("{}: doesn't support -i option", uucore::util_name());
             return Ok(());
         }
@@ -482,32 +475,34 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     Ok(())
 }
 
-pub fn uu_app<'a>() -> Command<'a> {
+pub fn uu_app() -> Command {
     Command::new(uucore::util_name())
         .version(crate_version!())
         .about(ABOUT)
         .override_usage(format_usage(USAGE))
-        .after_help(LONG_HELP)
+        .after_help(AFTER_HELP)
         .infer_long_args(true)
+        .disable_help_flag(true)
         .arg(
             Arg::new(OPT_HELP)
                 .long(OPT_HELP)
-                .help("Print help information."),
+                .help("Print help information.")
+                .action(ArgAction::Help),
         )
         .arg(
             Arg::new(OPT_ALL)
                 .short('a')
                 .long("all")
                 .overrides_with(OPT_ALL)
-                .help("include dummy file systems"),
+                .help("include dummy file systems")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_BLOCKSIZE)
                 .short('B')
                 .long("block-size")
-                .takes_value(true)
                 .value_name("SIZE")
-                .overrides_with_all(&[OPT_KILO, OPT_BLOCKSIZE])
+                .overrides_with_all([OPT_KILO, OPT_BLOCKSIZE])
                 .help(
                     "scale sizes by SIZE before printing them; e.g.\
                     '-BM' prints sizes in units of 1,048,576 bytes",
@@ -517,61 +512,67 @@ pub fn uu_app<'a>() -> Command<'a> {
             Arg::new(OPT_TOTAL)
                 .long("total")
                 .overrides_with(OPT_TOTAL)
-                .help("produce a grand total"),
+                .help("produce a grand total")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_HUMAN_READABLE_BINARY)
                 .short('h')
                 .long("human-readable")
-                .overrides_with_all(&[OPT_HUMAN_READABLE_DECIMAL, OPT_HUMAN_READABLE_BINARY])
-                .help("print sizes in human readable format (e.g., 1K 234M 2G)"),
+                .overrides_with_all([OPT_HUMAN_READABLE_DECIMAL, OPT_HUMAN_READABLE_BINARY])
+                .help("print sizes in human readable format (e.g., 1K 234M 2G)")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_HUMAN_READABLE_DECIMAL)
                 .short('H')
                 .long("si")
-                .overrides_with_all(&[OPT_HUMAN_READABLE_BINARY, OPT_HUMAN_READABLE_DECIMAL])
-                .help("likewise, but use powers of 1000 not 1024"),
+                .overrides_with_all([OPT_HUMAN_READABLE_BINARY, OPT_HUMAN_READABLE_DECIMAL])
+                .help("likewise, but use powers of 1000 not 1024")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_INODES)
                 .short('i')
                 .long("inodes")
                 .overrides_with(OPT_INODES)
-                .help("list inode information instead of block usage"),
+                .help("list inode information instead of block usage")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_KILO)
                 .short('k')
                 .help("like --block-size=1K")
-                .overrides_with_all(&[OPT_BLOCKSIZE, OPT_KILO]),
+                .overrides_with_all([OPT_BLOCKSIZE, OPT_KILO])
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_LOCAL)
                 .short('l')
                 .long("local")
                 .overrides_with(OPT_LOCAL)
-                .help("limit listing to local file systems"),
+                .help("limit listing to local file systems")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_NO_SYNC)
                 .long("no-sync")
-                .overrides_with_all(&[OPT_SYNC, OPT_NO_SYNC])
-                .help("do not invoke sync before getting usage info (default)"),
+                .overrides_with_all([OPT_SYNC, OPT_NO_SYNC])
+                .help("do not invoke sync before getting usage info (default)")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_OUTPUT)
                 .long("output")
-                .takes_value(true)
                 .value_name("FIELD_LIST")
-                .min_values(0)
+                .action(ArgAction::Append)
+                .num_args(0..)
                 .require_equals(true)
                 .use_value_delimiter(true)
-                .multiple_occurrences(true)
                 .value_parser(OUTPUT_FIELD_LIST)
-                .default_missing_values(&OUTPUT_FIELD_LIST)
-                .default_values(&["source", "size", "used", "avail", "pcent", "target"])
-                .conflicts_with_all(&[OPT_INODES, OPT_PORTABILITY, OPT_PRINT_TYPE])
+                .default_missing_values(OUTPUT_FIELD_LIST)
+                .default_values(["source", "size", "used", "avail", "pcent", "target"])
+                .conflicts_with_all([OPT_INODES, OPT_PORTABILITY, OPT_PRINT_TYPE])
                 .help(
                     "use the output format defined by FIELD_LIST, \
                      or print all fields if FIELD_LIST is omitted.",
@@ -582,22 +583,23 @@ pub fn uu_app<'a>() -> Command<'a> {
                 .short('P')
                 .long("portability")
                 .overrides_with(OPT_PORTABILITY)
-                .help("use the POSIX output format"),
+                .help("use the POSIX output format")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_SYNC)
                 .long("sync")
-                .overrides_with_all(&[OPT_NO_SYNC, OPT_SYNC])
-                .help("invoke sync before getting usage info (non-windows only)"),
+                .overrides_with_all([OPT_NO_SYNC, OPT_SYNC])
+                .help("invoke sync before getting usage info (non-windows only)")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_TYPE)
                 .short('t')
                 .long("type")
                 .value_parser(ValueParser::os_string())
-                .takes_value(true)
                 .value_name("TYPE")
-                .multiple_occurrences(true)
+                .action(ArgAction::Append)
                 .help("limit listing to file systems of type TYPE"),
         )
         .arg(
@@ -605,22 +607,22 @@ pub fn uu_app<'a>() -> Command<'a> {
                 .short('T')
                 .long("print-type")
                 .overrides_with(OPT_PRINT_TYPE)
-                .help("print file system type"),
+                .help("print file system type")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_EXCLUDE_TYPE)
                 .short('x')
                 .long("exclude-type")
+                .action(ArgAction::Append)
                 .value_parser(ValueParser::os_string())
-                .takes_value(true)
                 .value_name("TYPE")
                 .use_value_delimiter(true)
-                .multiple_occurrences(true)
                 .help("limit listing to file systems not of type TYPE"),
         )
         .arg(
             Arg::new(OPT_PATHS)
-                .multiple_occurrences(true)
+                .action(ArgAction::Append)
                 .value_hint(clap::ValueHint::AnyPath),
         )
 }
