@@ -22,10 +22,10 @@ use std::os::unix;
 #[cfg(windows)]
 use std::os::windows;
 use std::path::{Path, PathBuf};
-use uucore::backup_control::{self, BackupMode};
+use uucore::backup_control::{self, source_is_target_backup, BackupMode};
 use uucore::display::Quotable;
 use uucore::error::{set_exit_code, FromIo, UError, UResult, USimpleError, UUsageError};
-use uucore::fs::are_hardlinks_to_same_file;
+use uucore::fs::{are_hardlinks_or_one_way_symlink_to_same_file, are_hardlinks_to_same_file};
 use uucore::update_control::{self, UpdateMode};
 use uucore::{format_usage, help_about, help_section, help_usage, prompt_yes, show};
 
@@ -251,12 +251,25 @@ fn parse_paths(files: &[OsString], b: &Behavior) -> Vec<PathBuf> {
 }
 
 fn handle_two_paths(source: &Path, target: &Path, b: &Behavior) -> UResult<()> {
+    if b.backup == BackupMode::SimpleBackup && source_is_target_backup(source, target, &b.suffix) {
+        return Err(io::Error::new(
+            io::ErrorKind::NotFound,
+            format!(
+                "backing up {} might destroy source;  {} not moved",
+                target.quote(),
+                source.quote()
+            ),
+        )
+        .into());
+    }
     if source.symlink_metadata().is_err() {
         return Err(MvError::NoSuchFile(source.quote().to_string()).into());
     }
 
-    if (source.eq(target) || are_hardlinks_to_same_file(source, target))
-        && b.backup != BackupMode::SimpleBackup
+    if (source.eq(target)
+        || are_hardlinks_to_same_file(source, target)
+        || are_hardlinks_or_one_way_symlink_to_same_file(source, target))
+        && b.backup == BackupMode::NoBackup
     {
         if source.eq(Path::new(".")) || source.ends_with("/.") || source.is_file() {
             return Err(
