@@ -532,7 +532,9 @@ fn wipe_name(orig_path: &Path, verbose: bool) -> Option<PathBuf> {
                     }
 
                     // Sync every file rename
-                    let new_file = File::open(new_path.clone())
+                    let new_file = OpenOptions::new()
+                        .write(true)
+                        .open(new_path.clone())
                         .expect("Failed to open renamed file for syncing");
                     new_file.sync_all().expect("Failed to sync renamed file");
 
