@@ -1,4 +1,4 @@
-use crate::common::util::*;
+use crate::common::util::TestScenario;
 
 #[test]
 fn test_invalid_arg() {
@@ -29,7 +29,7 @@ fn test_link_no_circular() {
 
     ucmd.args(&[link, link])
         .fails()
-        .stderr_is("link: cannot create link 'test_link_no_circular' to 'test_link_no_circular': No such file or directory");
+        .stderr_is("link: cannot create link 'test_link_no_circular' to 'test_link_no_circular': No such file or directory\n");
     assert!(!at.file_exists(link));
 }
 
@@ -41,7 +41,7 @@ fn test_link_nonexistent_file() {
 
     ucmd.args(&[file, link])
         .fails()
-        .stderr_only("link: cannot create link 'test_link_nonexistent_file_link' to 'test_link_nonexistent_file': No such file or directory");
+        .stderr_only("link: cannot create link 'test_link_nonexistent_file_link' to 'test_link_nonexistent_file': No such file or directory\n");
     assert!(!at.file_exists(file));
     assert!(!at.file_exists(link));
 }
@@ -50,9 +50,9 @@ fn test_link_nonexistent_file() {
 fn test_link_one_argument() {
     let (_, mut ucmd) = at_and_ucmd!();
     let file = "test_link_argument";
-    ucmd.args(&[file]).fails().stderr_contains(
-        "error: The argument '<FILES>...' requires at least 2 values but only 1 was provided",
-    );
+    ucmd.args(&[file])
+        .fails()
+        .stderr_contains("2 values required");
 }
 
 #[test]
@@ -63,7 +63,7 @@ fn test_link_three_arguments() {
         "test_link_argument2",
         "test_link_argument3",
     ];
-    ucmd.args(&arguments[..]).fails().stderr_contains(
-        format!("error: The value '{}' was provided to '<FILES>...' but it wasn't expecting any more values", arguments[2]),
-    );
+    ucmd.args(&arguments[..])
+        .fails()
+        .stderr_contains("2 values required");
 }
