@@ -35,6 +35,11 @@ fn test_invalid_arg() {
     new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
 }
 
+#[test]
+fn test_version() {
+    new_ucmd!().arg("--version").succeeds();
+}
+
 #[test]
 fn test_simple() {
     run(NO_ARGS, b"y\ny\ny\ny\n");
